("a modifier" "a kombitast")
("GNU" "GNU")
("h modifier" "h kombitast")
("LaTeX" "LaTeX")
("m modifier" "m kombitast")
("TeX" "TeX")
("abbreviation" "forkortelse")
("about" "om")
("about menu" "om menu")
("above" "over")
("abstract" "abstract")
("accent" "accent")
("accept" "acceptr")
("accept all scripts" "acceptr alle scripts")
("accept no scripts" "acceptr ingen scripts")
("accept script" "acceptr script")
("acknowledgment" "anerkendelse")
("acronym" "akronym")
("action" "handling")
("activate" "aktivr")
("acute" "aigu")
("add switch after" "tilfj kontakt efter")
("add switch before" "tilfj kontakt fr")
("address" "addresse")
("address block" "addresseomrde")
("advanced" "avanceret")
("advanced layout features" "avancerede layout funktioner")
("after" "efter")
("albanian" "albansk")
("algorithm" "algoritme")
("align cell to the bottom" "justr celle med bund")
("align cell to the left" "justr celle med venstre side")
("align cell to the right" "justr celle med hjre side")
("align cell to the top" "justr celle med top")
("align table at base of left column" "justr tabel med bunden af venstre sjle")
("align table at base of middle column" "justr tabel med bunden af midterste sjle")
("align table at base of origin column" "justr tabel med bunden af basissjle")
("align table at base of right column" "justr tabel med bunden af hjre sjle")
("align table at fraction bar height" "justr tabel til brker")
("align table at the base of bottom row" "justr tabel med bunden af bundrkken")
("align table at the base of middle row" "justr tabel med bunden af  midterste rkke")
("align table at the base of origin row" "justr tabel med bunden af basisrkken")
("align table at the base of top row" "justr tabel med bunden af toprkken")
("align table at the bottom" "justr tabel med bunden")
("align table at the center" "justr tabel med centrum")
("align table at the horizontal center" "justr tabel med vandret centrum")
("align table at the left" "justr tabel med venstre side")
("align table at the top" "justr tabel med top")
("align table to the right" "justr tabel med hjre side")
("align text to the left" "venstrejustret tekst")
("align text to the right" "hjrejustret tekst")
("aligned" "justeret")
("alignment" "justering")
("all" "alle")
("allow" "tillad")
("allowed extension" "tilladt udvidelse")
("allowed reduction" "tilladt reducring")
("alpha release" "alpha udgave")
("alt key" "alt tast")
("and" "og")
("appendix" "appendix")
("apply" "tilfj")
("april" "april")
("arab" "arabisk")
("archaic" "arkisk")
("architecture" "arkitektur")
("argument" "argument")
("arithmetic" "aritmetik")
("armenian" "armensk")
("arrow" "pil")
("arrows" "pile")
("article" "artikel")
("as on paper" "som p papir")
("assign" "fastst")
("at fraction bar height" "til brkstregshjde")
("at the baseline" "til basislinie")
("at the bottom" "til bunden")
("at the left" "til venstre side")
("at the middle" "til midten")
("at the right" "til hjre side")
("at the top" "til toppen")
("attach" "tilfj")
("attach buffer to which project" "tilfj buffer til hvilket projekt")
("august" "august")
("author" "forfatter")
("authorize" "tillad")
("automatic" "automatisk")
("automatically close brackets" "luk paranteser automatisk")
("automatically generated content" "automatisk genreret indhold")
("axiom" "axiom")
("background" "baggrund")
("background color" "baggrundsfarve")
("backward replace" "erstat baglns")
("backward search" "sg baglns")
("bad data format" "forkert data-format")
("bar" "bjlke")
("bard" "skjald")
("base level" "basisniveau")
("bashkirian" "bashkirisk")
("basic" "grundliggende")
("basic data types" "grundliggende datatyper")
("basic types" "grundliggende typer")
("be useful" "vre nyttigt")
("become a TeXmacs developer" "bliv TeXmacs udvikler")
("before" "fr")
("begin" "begynd")
("below" "efter")
("beta release" "beta udgave")
("bibliography" "bibliografi")
("bibliography file" "bibliografiarkiv")
("bibliography style" "bibliografiopstning")
("big" "stor")
("big figure" "stor figur")
("big operator" "stor operator")
("big skip" "stort mellemrum")
("big table" "stor tabel")
("binary operation" "binr operation")
("binary relation" "binr relation")
("black" "sort")
("blackboard bold" "blackboard, fed")
("blackboard math" "blackboard math")
("blackletter" "gotisk skrift")
("blue" "bl")
("body" "brdtekst")
("bold" "fed")
("book" "bog")
("border" "kant")
("both" "begge")
("bottom" "bund")
("bottom border" "bundkant")
("bottom margin" "bundmargen")
("bottom padding" "bundmellemrum")
("branch" "gren")
("break" "linieudgang")
("breaking" "ombrydning")
("breve" "petit")
("british" "britisk")
("broken white" "brkket hvid")
("brown" "brun")
("browse" "gennemse")
("browse web" "kig p internettet")
("browser" "browser")
("buffer" "buffer")
("bulgarian" "bulgarsk")
("bullet" "bullit")
("bullets" "bulitter")
("by" "af")
("by typing" "ved maskinskrivning")
("bytes free" "bytes ubrugt")
("bytes used" "bytes brugt")
("calligraphic" "kalligrafisk")
("cancel" "annullr")
("caps-lock key" "skiftels tasten")
("case" "tilflde")
("cc" "kapitler")
("cell" "celle")
("cell background color" "celle baggrundsfarve")
("cell border" "cellekant")
("cell height" "cellehjde")
("cell operation mode" "celle virkningsmde")
("cell width" "cellebredde")
("center" "centrr")
("center text" "centrr tekst")
("centered" "centreret")
("centered block" "centreret blok")
("centered tabular" "centeret tabel")
("change border of cell" "skift cellekant")
("change cell operation mode" "skrift cellefunktion")
("change log" "seneste ndringer")
("changes" "ndringer")
("chapter" "kapitel")
("check" "kontrollr")
("check text for spelling errors" "kontrollr tekst for stavefejl")
("chinese" "kinesisk")
("choice" "valg")
("citation" "citat")
("cite" "citr")
("class" "klasse")
("clear" "slet")
("clear selection" "slet det valgte")
("clipped" "beskret")
("clipped and magnified" "beskret og forstrret")
("clipped and resized" "beskret og omformet")
("clone" "duplikr")
("clone window" "duplikr vindue")
("close" "luk")
("close TeXmacs" "luk Texmacs")
("close buffer" "luk buffer")
("close session" "luk session")
("close window" "luk vindue")
("closing" "lukker")
("code" "kode")
("color" "farve")
("column" "sjle")
("column contains glued items" "sjle indeholder faste genstande")
("compact" "kompakt")
("compatibility with other formats" "kompatiblilitet med andre formater")
("compile article" "sammenst artikel")
("compile book" "sammenst bog")
("compile buffer" "sammenst buffer")
("compile project" "sammenst projekt")
("complex" "kompleks")
("concrete" "concrete")
("condensed" "sammentrukket")
("condition" "betingelse")
("configuration" "konfiguration")
("content" "indhold")
("content tag" "indholdstype")
("context dependent icons" "kontekstafhngige ikoner")
("continuation of" "fortsttelse af")
("convention" "konvention")
("converters to other data formats" "oversttere til andre formater")
("copy" "kopir")
("copy text" "kopir tekst")
("copy to" "kopir til")
("copying" "kopierer")
("corollary" "resultat")
("correct text" "ret tekst")
("cursors" "indstningsmrker")
("custom tab" "tilpasset tabulator")
("customizing TeXmacs" "tilpas TeXmacs")
("customizing the TeXmacs styles" "tilpasser TeXmacs's opstninger")
("custum tab" "tilpasset tabulator")
("cut" "klip")
("cut text" "klip tekst")
("cut to" "klip til")
("cypriot" "cypriot")
("cyrillic" "kyrillisk")
("cyrillic input method" "kyrillisk input metode")
("cyrillic italic right" "kyrillisk kursiv hjre")
("czech" "tjekkisk")
("dancers" "dansere")
("danish" "dansk")
("dark grey" "mrk gr")
("dash" "bindestreg")
("dashes" "bindestreger")
("data conversion" "data ")
("data format" "data-format")
("date" "dato")
("deactivate" "deaktivr")
("deactivate table" "deaktivr tabel")
("december" "december")
("decorate atoms" "dekorationsatomer")
("default" "standard")
("default padding" "standardmellemrum")
("definition" "definition")
("delete" "slet")
("delete column" "slet sjle")
("delete row" "slet rkke")
("denominator" "nvner")
("description" "beskrevet liste")
("destination" "destination")
("detach" "adskil")
("determinant" "determinant")
("devangari" "devangari")
("developers guide" "udviklerguide")
("directory" "mappe")
("disable first indentation" "sl frste indrykning fra")
("disable first indentation after" "sl 'frste indrykning efter' fra")
("disable first indentation before" "sl 'frste indrykning fr' fra")
("disable indentation" "sl indrykning fra")
("disable indentation after" "sl 'indrykning efter' fra")
("disable indentation before" "sl 'indrykning fr' fra")
("disallow" "ngt")
("distribute unused space" "fordel ubrugt plads")
("div" "div")
("do not remap" "ingen ndring")
("document" "dokument")
("document format" "dokumentformat")
("document style" "dokumenttypografi")
("document styles" "dokumenttypografier")
("documentation" "dokumentation")
("documents are trees" "dokumenter er trer")
("dot" "prik")
("dots" "prikker")
("double stroke" "dobbelt streg")
("down" "ned")
("dpi" "dpi")
("duplicate" "dublr")
("dutch" "hollandsk")
("dynamic libraries" "dynamiske biblioteker")
("edit" "rediger")
("editing tools" "redigeringsvrktjer")
("email" "e-post")
("emphasize" "fremhv")
("emphasize text" "skriv fremhvet tekst")
("empty box" "tm kasse")
("enable first indentation" "sl frste indrykning til")
("enable first indentation after" "sl 'frste indrykning efter' til")
("enable first indentation before" "sl 'frste indrykning fr' til")
("enable indentation" "sl indrykning til")
("enable indentation after" "sl 'indrykning efter' til")
("enable indentation before" "sl 'indrykning fr' til")
("encl" "encl")
("end" "slut")
("english" "engelsk")
("enter a title" "skriv en titel")
("enumerate" "nummereret liste")
("enumerate|Alpha" "nummereret|Alpha")
("enumerate|Roman" "nummereret|Roman")
("enumerate|alpha" "nummereret|alpha")
("enumerate|roman" "nummereret|roman")
("env" "omr")
("environment" "omrde")
("epilogue" "epilog")
("equal" "lig")
("equation" "ligning")
("equations" "ligninger")
("equivalent for" "lig med")
("error" "fejl")
("esperanto" "esperanto")
("etruscan" "etruskisk")
("evaluate" "udregn")
("evaluate scheme expression" "udregn scheme udtryk")
("even page footer" "lige siders sidefod")
("even page header" "lige siders sidehoved")
("even page margin" "lige sider margen")
("even page text" "lige siders tekst")
("exact horizontal" "njagtig vandret")
("exact mode" "njagtig")
("exam" "eksamen")
("example" "eksempel")
("exclusive" "eksklusiv")
("exclusive or" "eksklusiv eller")
("executable" "udfrbar")
("execute" "udfr")
("execute a TeXmacs command" "udfr en TeXmacskommando")
("execute system command" "udfr en systemkommando")
("executive" "executive")
("exercise" "velse")
("expand" "udvid")
("explained" "forklaret")
("export" "eksportr")
("export as" "eksportr som")
("extend or normal" "udvid eller normal")
("extern " "ekstern")
("extra" "ekstra")
("extract format" "trk format ud")
("family" "familie")
("february" "februar")
("figure" "figur")
("file" "arkiv")
("file name" "dokumentnavn")
("file not found" "kunne ikke finde dokument")
("find next match" "find nste")
("find text" "find tekst")
("finnish" "finsk")
("first contact" "frste kontakt")
("first indentation" "frste indrykning")
("first item" "frste genstand")
("first page" "frste side")
("first start" "frste begyndelse")
("flat" "flad")
("flexibility" "fleksibilitet")
("flexibility factor for vertical spacing" "fleksibilitetsfaktor for lodrette mellemrum")
("floating figure" "flydende figur")
("floating object" "flydende objekt")
("floating table" "flydende tabel")
("fold" "fold")
("folded" "foldet")
("font" "skrift")
("font base size" "basis skriftstrrelse")
("font dpi" "skrift dpi")
("font family" "skriftfamilie")
("font name" "skriftnavn")
("font series" "skriftserie")
("font shape" "skriftform")
("font size" "skriftstrrrelse")
("font variant" "skriftvariant")
("fonts" "skrifter")
("footer" "sidefod")
("footnote" "fodnote")
("for" "for")
("foreground" "forgrund")
("foreign" "udlandsk")
("format" "format")
("formatted date" "formateret dato")
("formula" "formel")
("formula style" "formeltypografi")
("forward replace" "forlns erstat")
("forward search" "forlns sgning")
("fraction" "brk")
("french" "fransk")
("full manuals" "hele brugerhndbger")
("function" "funktion")
("further customization" "yderligere tilpasning")
("future changes" "fremtidige ndringer")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs kommer uden nogen former for garanti")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs er distriburet under GNU general public license")
("general architecture of TeXmacs" "TeXmacs' overordnede struktur")
("general negation" "generel negation")
("generating font file" "genererer skrifthjlpefil")
("generic" "standard")
("georgian" "georgisk")
("german" "tysk")
("getting started" "kom igang")
("glossary" "ordforklaring")
("glossary entry" "ordforklaringspunkt")
("glue" "lim")
("glue decorations" "lim dekorationer")
("go" "g")
("gothic" "gotisk")
("graphical interface" "grafisk grnseflade")
("grave" "accent grave")
("greater" "strre")
("greater or equal" "strre eller lig")
("greek" "grsk")
("greek letter" "grsk bogstav")
("green" "grn")
("grey" "gr")
("group" "gruppe")
("happy typing" "gldelig skrivning")
("has been aborted" "er blevet afbrudt")
("has completed its task" "har afsluttet sin opgave")
("hat" "hat")
("header" "sidehoved")
("header and footer" "sidehoved og sidefod")
("hebrew" "hebraisk")
("height" "hjde")
("height is exactly the specified height" "hjde er prcis den specificerede hjde")
("height is maximum of specified height and box height" "hjde er maksimum af den specificerede hjde og kassehjde")
("height is minimum of specified height and box height" "hjde er minimum af den specificerede hjde og kassehjde")
("height magnification" "hjde forstrrelse")
("help" "hjlp")
("help me" "hjlp mig")
("help us" "hjlp os")
("here" "her")
("home" "hjem")
("horizontal" "vandret")
("horizontal cell alignment" "vandret cellejustering")
("horizontal ink separation" "vandret blkseperation")
("horizontal part" "vandret del")
("horizontal position" "horisontal placering")
("horizontal space" "vandret mellemrum")
("horizontal table alignment" "vandret tabeljustering")
("horizontally align cell to the base" "justr celle til bunden vandret")
("horizontally center the cell" "centrr celle vandret")
("how much longer may pages become" "hvor meget lngere m sider vre")
("how much shorter may pages become" "hvor meget kortere m sider vre")
("huge" "enorm")
("hungarian" "ungarnsk")
("hyperlink" "hyperlink")
("hyphenation" "orddeling")
("icelandic" "islandsk")
("if" "hvis")
("image" "billede")
("image links" "billedelinks")
("implementation" "implementation")
("import" "importr")
("improving the current implementation" "forbedring af den nuvrende implementation")
("inactive" "inaktiv")
("include" "inkludr")
("include a document" "inkludr et dokument")
("include file" "inkludr et arkiv")
("inclusion into TeXmacs" "inklusioner i TeXmacs")
("inclusions" "inklusioner")
("indent" "indrykning")
("indentation flag" "indrykningsflag")
("index" "index")
("index entry" "indexpunkt")
("index level" "indexniveau")
("insert" "indst")
("insert Pr" "indst Pr")
("insert a TeXmacs symbol" "indst et TeXmacssymbol")
("insert a big operator" "indst en stor operator")
("insert a binary operation" "indst en binr operator")
("insert a binary relation" "indst en binr relation")
("insert a blackboard bold character" "indst et fedt blackboardtegn")
("insert a bold calligraphic character" "indst et fedt kalligrafisk tegn")
("insert a bold character" "indst et fedt tegn")
("insert a calligraphic character" "indst et kalligrafisk tegn")
("insert a fraction" "indst en brk")
("insert a fraktur character" "indst et frakturtegn")
("insert a greek character" "indst et grsk bogstav")
("insert a large left delimiter" "indst et stort venstre afgrnsetegn")
("insert a large right delimiter" "indst et stort hjre afgrnsetegn")
("insert a large separator" "indst en stor adskiller")
("insert a left subscript" "indst venstre indextegn")
("insert a link" "indst et link")
("insert a miscellaneous symbol" "indst diverse symboler")
("insert a new branch" "indst en ny forgrening")
("insert a new item" "indst et nyt element")
("insert a picture" "indst et billede")
("insert a square root" "indst kvadratrod")
("insert a table" "indst en tabel")
("insert a table or a matrix" "indst en tabel eller en matrix")
("insert a wide symbol above" "indst et bredt symbol over")
("insert a wide symbol below" "indst et bredt symbol under")
("insert an" "indst en")
("insert an accent" "indst en accent")
("insert an arrow" "indst en pil")
("insert an environment" "indst et omrde")
("insert an n" "indst en n")
("insert appendix" "indst appendix")
("insert arccos" "indst arccos")
("insert arcsin" "indst arcsin")
("insert arctan" "indst arctan")
("insert arg" "indst arg")
("insert argument" "indst argument")
("insert automatically generated content" "indst automatisk genereret indhold")
("insert big contour integral" "indst stort kant-integrale")
("insert big coproduct" "indst stort co-product")
("insert big direct sum" "indst stor direkte sum")
("insert big dotted point" "indst stor prik-punkt")
("insert big integral" "indst stort integrale")
("insert big intersection" "indst stort skringspunkt")
("insert big logical and" "indst stor logisk og")
("insert big logical or" "indst stor logisk eller")
("insert big product" "indst stort produkt")
("insert big square union" "indst stort kvardratenhed")
("insert big summation" "indst stor summation")
("insert big tensor product" "indst stort tensorprodukt")
("insert big union" "indst stor fllesmngde")
("insert big union sum" "indst stor fllessum")
("insert big vertical space" "indst stor lodret afstand")
("insert chapter" "indst kapitel")
("insert column" "indst sjle")
("insert column to the left" "indst sjle til venstre")
("insert column to the right" "indst sjle til hjre")
("insert cos" "indst cos")
("insert cosh" "indst cosh")
("insert cot" "indst cot")
("insert coth" "indst coth")
("insert csc" "indst csc")
("insert deg" "indst deg")
("insert det" "indst det")
("insert dim" "indst dim")
("insert dollar" "indst dollar")
("insert equation" "indst ligning")
("insert executable markup" "indst udfrbar markup")
("insert exp" "indst exp")
("insert footnote" "indst fodnote")
("insert formula" "indst formel")
("insert gcd" "indst gcd")
("insert hom" "indst hom")
("insert horizontal interword space" "indst vandret mellemrum mellem ord")
("insert image" "indst billede")
("insert inactive markup" "indst inaktiv markup")
("insert inf" "indst inf")
("insert ker" "indst ker")
("insert lg" "indst lg")
("insert lim" "indst lim")
("insert liminf" "indst liminf")
("insert limsup" "indst limsup")
("insert ln" "indst ln")
("insert log" "indst log")
("insert mathematics" "indst formler")
("insert max" "indst maks")
("insert medium horizontal space" "indst medium vandret mellemrum")
("insert medium vertical space" "indst medium lodret mellemrum")
("insert min" "indst min")
("insert negative horizontal space" "indst negativt vandret mellemrum")
("insert new item or number" "indst nyt punkt eller nummer")
("insert new rows or columns" "indst nye rkker eller sjler")
("insert or delete rows or columns" "indst eller slet rkker eller sjler")
("insert row" "indst rkke")
("insert row above" "indst rkke over")
("insert row below" "indst rkke under")
("insert sec" "indst sec")
("insert section" "indst afsnit")
("insert sharp" "indst sharp")
("insert sin" "indst sin")
("insert sinh" "indst sinh")
("insert small horizontal space" "indst lille vandret mellemrum")
("insert small vertical space" "indst lille lodret mellemrum")
("insert structural markup" "indst strukturel markup")
("insert subsection" "indst underafsnit")
("insert subsubsection" "indst underunderafsnit")
("insert sup" "indst sup")
("insert tan" "indst tan")
("insert tanh" "indst tanh")
("insert thick horizontal space" "indst tyk vandret mellemrum")
("interfacing" "grnseflader")
("interfacing TeXmacs with other systems" "TeXmacs og andre systemer")
("interjection" "interjektion")
("interline separation" "seperation mellem linier")
("interline space" "mellemrum mellem linier")
("internationalization" "internationalisering")
("interparagraph space" "mellemrum mellem paragraffer")
("interrupt execution" "afbryd krsel")
("introduction" "introduktion")
("invisible" "usynlig")
("invisible citation" "usynlig citering")
("irish" "irsk")
("is running" "krer")
("is tuple" "er en tupel")
("ispell does not respond" "ispell reagerer ikke")
("ispell is already busy" "ispell har travlt nok i forvejen")
("italian" "italiensk")
("italic" "kursiv")
("italic right" "hjre kursiv")
("itemize" "liste")
("january" "januar")
("japanese" "japansk")
("july" "juli")
("june" "juni")
("justified" "justeret")
("justify text" "justr tekst")
("key" "tast")
("keyboard" "tastatur")
("keyboard equivalent" "tastaturgenvej")
("keyboard modifiers" "kombitaster")
("keyboard shortcut" "tastaturgenvej")
("keymaps" "tastaturlayout")
("keyword" "ngleord")
("keywords" "ngleord")
("kill" "kill")
("known bugs" "kendte fejl")
("label" "mrke")
("landscape" "landskab")
("language" "sprog")
("large" "stor")
("large closing bracket" "stor lukkeparantes")
("large delimiter" "stor afgrnsetegn")
("large opening bracket" "stor bneparantes")
("large separator" "stor adskiller")
("last page" "sidste side")
("latex command" "latex kommando")
("latin" "latin")
("layout" "layout")
("left" "venstre")
("left arrow" "venstrepil")
("left border" "venstre ramme")
("left margin" "venstre margen")
("left padding" "venstre mellemrum")
("left prime" "venstre primre")
("left aligned" "venstrejusteret")
("left slanted" "venstre skrnende")
("left subscript" "indextegn til venstre")
("left superscript" "potenstegn til venstre")
("left surrounding" "venstre nrhed")
("legal" "legal")
("lemma" "lemma")
("length" "lngde")
("less" "mindre")
("less or equal" "mindre eller lig")
("letter" "brev")
("license" "licens")
("light" "lys")
("light grey" "lys gr")
("limitations" "begrnsninger")
("limits" "grnser")
("line" "linie")
("line break" "linieskift")
("line stretch" "liniestrkning")
("link" "link")
("link image" "link billede")
("list" "liste")
("list of figures" "figurliste")
("list of tables" "tabelliste")
("load" "indls")
("load LaTeX file" "ben LaTeX-dokument")
("load TeX file" "ben TeX-dokument")
("load TeXmacs file" "ben TeXmacs-dokument")
("load TeXmacs style file" "indls TeXmacs-typografi")
("load a file" "ben et arkiv")
("load buffer" "ben en buffer")
("load file" "ben arkiv")
("load html file" "ben html-dokument")
("load image" "indls billede")
("load in new window" "ben i nyt vindue")
("load latex file" "ben latex-dokument")
("load more recent autosave file" "ben nyere automatisk gemt udgave")
("load tex file" "ben tex-dokument")
("load verbatim file" "ben tekst-dokument")
("loaded" "indlst")
("long" "lang")
("look and feel" "udseende")
("look up" "sl op")
("lower border" "nedre ramme")
("macro" "makro")
("magenta" "magenta")
("magic" "magisk")
("magnification" "forstrrelse")
("magnified" "forstrret")
("main" "primr")
("main icon bar" "primre ikonbjlke")
("major changes" "store ndringer")
("make a page insertion" "sideindstning")
("make a subscript" "indst et indextegn")
("make a superscript" "indst et potenstegn")
("make acute" "indst aigu")
("make bar" "lav bjlke")
("make check" "lav check")
("make fraction" "indst brk")
("make grave" "indst accent grave")
("make hat" "indst hat")
("make label" "indst mrke")
("make negation" "indst negation")
("make page reference" "indst sidehenvisning")
("make reference" "indst henvisning")
("make square root" "kvadratrod")
("make tilde" "indst tilde")
("make title" "indst titel")
("make vector" "indst vektor")
("making donations" "donationer")
("manual" "brugerhndbog")
("map to" "ndrer til")
("march" "marts")
("margins" "margener")
("margins as on paper" "margener som p papir")
("master" "hoveddokument")
("master file" "hoveddokument")
("math" "formler")
("math font" "formelskrift")
("math font family" "formelskriftfamilie")
("math font series" "formelskriftserie")
("math font shape" "formelskriftform")
("mathematical" "matematisk")
("mathematical formulas" "matematiske formler")
("mathematical typesetting" "matematisk typografi")
("mathematics" "formler")
("matrix" "matrix")
("maximal number of columns" "maksimale antal sjler")
("maximal number of rows" "maksimale antal rkker")
("maximum mode" "maksimal")
("may" "maj")
("medium" "medium")
("medium skip" "medium mellemrum")
("meminfo" "meminfo")
("merge" "sammenlg")
("messy" "messy")
("meta key" "meta tast")
("middle" "midten")
("minimal number of columns" "minimale antal sjler")
("minimal number of rows" "minimale antal rkker")
("minimum mode" "minimal")
("minus" "minus")
("miscellaneous" "diverse")
("mod" "mod")
("mode" "tilstand")
("modifier" "kombitast")
("modify cell alignment" "ndring af cellejustering")
("modify cell border" "ndring af cellekant")
("modify cell padding" "ndring af cellemellemrum")
("modify cell size" "ndring af cellestrrelse")
("modify table border" "ndring af tabelkant")
("modify table padding" "ndring af tabelmellemrum")
("mongolian" "mongolsk")
("more information about GNU TeXmacs can be found in the help" "mere information om GNU TeXmacs kan findes i hjlp")
("mosaic" "mosaik")
("move down" "flyt ned")
("move object" "flyt objekt")
("move to the right when finished" "flyt til hjre bagefter")
("move up" "flyt op")
("n-th" "n-te")
("n-th root" "n-te rod")
("name" "navn")
("negation" "negation")
("new" "ny")
("new buffer" "ny buffer")
("new column" "ny sjle")
("new item" "nyt punkt")
("new line" "ny linie")
("new number" "nyt nummer")
("new page" "ny side")
("new page before" "ny side fr")
("new paragraph" "ny paragraf")
("new roman" "new roman")
("new row" "ny rkke")
("new table" "ny tabel")
("next line" "nste linie")
("no changes need to be saved" "der er ikke brug for at arkivere ndringer")
("no dictionary for" "ingen ordbog til")
("no first indentation" "ingen frste indrykning")
("no indentation" "ingen indrykning")
("no line break" "ingen linieskift")
("no matches found" "ingen magen til fundet")
("no more matches for" "ikke flere mage til")
("no more redo information available" "ikke flere gentagetrin tilgngelige")
("no more undo information available" "ikke flere fortrydelsestrin tilgngelige")
("no name" "uden navn")
("no page break after" "intet sideskift efter")
("no page break before" "intet sideskift fr")
("no spelling errors found in text" "der blev ikke fundet nogen stavefejl i teksten")
("no style" "ingen typografi")
("none" "ingen")
("normal" "normal")
("norwegian" "norsk")
("not" "ikke")
("not equal" "ikke lig")
("not found" "ikke fundet")
("notation" "notering")
("note" "note")
("november" "november")
("number" "nummer")
("number of columns" "antal spalter")
("number equation" "nummerr ligning")
("numbered equation" "nummereret ligning")
("numbered equations" "nummererede ligninger")
("numerator" "nummerator")
("numeric" "numerisk")
("objectives" "ml")
("occurrences" "forekomster")
("october" "oktober")
("odd page footer" "ulige siders sidefod")
("odd page header" "ulige siders sidehoved")
("odd page margin" "ulige siders margen")
("odd page text" "ulige siders tekst")
("off" "fra")
("ok" "ok")
("old english" "gammelt engelsk")
("old slavonic" "gammel slavisk")
("old style" "gammelt udseende")
("on" "til")
("on cells" "p celler")
("on columns" "p sjler")
("on entire table" "p hele tabellen")
("on rows" "p rkker")
("one spelling error has been corrected" "der er rettet n stavefejl")
("online documentation" "online dokumentation")
("online help" "online hjlp")
("open" "ben")
("open a new buffer" "ben en ny buffer")
("open new window" "ben nyt vindue")
("opening" "bner")
("operation on named selection" "operation p det nvnte valgte")
("operation on primary selection" "operation p det primrt valgte")
("operation on secondary selection" "operation p det sekundrt valgte")
("operation on ternary selection" "operation p det tertirt valgte")
("optical" "optisk")
("option" "indstilling")
("options" "indstillinger")
("or" "eller")
("orange" "orange")
("orientation" "orientering")
("origin" "oprindelse")
("original welcome message" "original velkomstbesked")
("other" "andre")
("other pages" "andre sider")
("other projects" "andre projekter")
("other style" "anden typografi")
("outlined roman" "kontureret serif")
("over" "over")
("overbrace" "overbrace")
("overline" "linie over")
("padding" "mellemrum")
("page" "side")
("page bottom margin" "nederste sidemargen")
("page break" "sideskift")
("page break before" "sideskift fr")
("page height" "side hjde")
("page insertion" "sideindstning")
("page layout" "sidelayout")
("page number text" "sidenummertekst")
("page numbering" "sidenummerering")
("page reference" "sidehenvisning")
("page right margin" "hjre sidemargen")
("page setup" "sideopstning")
("page top margin" "verste sidemargen")
("page type" "side type")
("page width" "sidebredde")
("paper" "papir")
("paper type" "papirtype")
("papyrus" "papyrus")
("paragraph" "paragraf")
("paragraph mode" "paragraftilstand")
("paragraph width" "paragrafbredde")
("part" "del")
("past changes" "tidligere ndringer")
("paste" "st ind")
("paste from" "st ind fra")
("paste text" "indst tekst")
("path" "sti")
("perform operations on cells" "udfr handlinger p enkelte celler")
("perform operations on columns" "udfr handlinger p sjler")
("perform operations on entire table" "udfr handlinger p hele tabellen")
("perform operations on rows" "udfr handlinger p rkker")
("permanent" "permanent")
("person" "person")
("personal dictionary has been modified" "brugerordbogen er blevet ndret")
("phantasy" "fantasi")
("philosophy" "filosofi")
("phoenician" "phnikisk")
("phonetic" "phonetisk")
("pink" "pink")
("plain block" "normal blok")
("plain tabular" "normal tabel")
("planned changes" "planlagte ndringer")
("plans for the future" "fremtidsplaner")
("please" "venligst")
("please wait" "vent venligst")
("plus" "plus")
("polish" "polsk")
("porting TeXmacs to other platforms" "overfre TeXmacs til andre platforme")
("portrait" "portrt")
("portuguese" "portugisisk")
("position" "position")
("position float" "placr flyder")
("position floating object" "placr flydende objekt")
("position the table" "placr tabellen")
("postscript" "postscript")
("postscript image" "postscript-billede")
("pre-alpha release" "praplha udgave")
("preamble" "forord")
("preamble mode" "forords tilstand")
("preferences" "indstillinger")
("presentation" "prsentation")
("presentation mode" "prsentationstilstand")
("preview before printing" "se eksempel fr udskrivning")
("preview with ghostview" "se eksempel med ghostview")
("primary" "primr")
("prime" "frste")
("print" "udskriv")
("print all" "udskriv alle")
("print all to file" "udskriv alle til arkiv")
("print page selection" "udskriv det valgte")
("print page selection to file" "udskriv det valgte til arkiv")
("print to postscript file" "udskriv til postscriptarkiv")
("printer" "printer")
("printer dpi" "printer oplsning")
("printing command" "udskrivnings kommando")
("problem" "probelm")
("professional" "professionel")
("prog" "prog")
("prog font" "progskrift")
("prog font family" "progskriftfamilie")
("prog font series" "progskriftserie")
("prog font shape" "progskriftform")
("program" "program")
("program mode" "program tilstand")
("programming" "programmering")
("progressive" "progressivt")
("project" "projekt")
("projects" "projekter")
("prologue" "prolog")
("prompt on scripts" "sprg ved scripts")
("proof" "bevis")
("proportional" "proportionel")
("proportional typewriter" "proportionel skrivemaskine")
("proposition" "forslag")
("query replace" "sg erstat")
("quit" "slut")
("quotation" "citat")
("quote" "citering")
("range" "interval")
("really close it" "vil du virkelig lukke den")
("really huge" "virkelig enorm")
("really quit" "vil du virkelig slutte")
("red" "rd")
("redo" "gentag")
("redo undone changes" "gentag fortrudte handlinger")
("reduce bottom margin by" "reducr bund margen med")
("reduce left margin by" "reducr venstre margen med")
("reduce margins" "reducr margener")
("reduce right margin by" "reducr hjre margen med")
("reduce top margin by" "reducr top margen med")
("reduction even page margin" "reduktion af lige siders margen")
("reduction odd page margin" "reduktion af ulige siders margen")
("reduction page bottom margin" "reduktion af bundmargen")
("reduction page right margin" "reduktion af hjre margen")
("reduction page top margin" "reduktion af topmargen")
("reference" "henvisning")
("references" "henvisninger")
("regular" "normal")
("release" "udgave")
("reload" "genindls")
("remark" "bemrkning")
("remove number" "fjern nummer")
("remove this switch" "fjern denne kontakt")
("renumber this page" "renummerr denne side")
("repeat object" "gentag objekt")
("replace" "erstat")
("replace by" "erstat med")
("replaced" "erstattet")
("replaced one occurrence" "n forekomst erstattet")
("reset" "nulstil")
("resize object" "skalr")
("resized" "skaleret")
("return" "retur")
("revert" "hent seneste")
("revert buffer" "hent seneste buffer")
("right" "hjre")
("right arrow" "hjrepil")
("right border" "hjre ramme")
("right margin" "hjre margen")
("right padding" "hjre mellemrum")
("right aligned" "hjrejusteret")
("right subscript" "indextegn til hjre")
("right superscript" "potenstegn til hjre")
("right surrounding" "hjre nrhed")
("rigid" "stift")
("rigid horizontal" "vandret stift")
("rigid space" "stift mellemrum")
("romanian" "romnsk")
("root" "root")
("rotate backward" "rotr forlns")
("rotate forward" "rotr baglns")
("row" "rkke")
("row contains glued items" "rkke indeholder faste genstande")
("runic" "runer")
("running author" "lbende forfatter")
("running title" "lbende titel")
("russian" "russisk")
("sample" "eksempel")
("sans serif" "sans serif")
("save" "arkivr")
("save TeXmacs file" "arkivr TeXmacs-dokument")
("save TeXmacs style file" "arkivr TeXmacs-typografidokument")
("save as" "arkivr som")
("save as LaTeX" "arkivr som LaTeX")
("save as TeX" "arkivr som TeX")
("save buffer" "arkivr buffer")
("save buffer as" "arkivr buffer som")
("save file" "arkivr dokument")
("save html file" "arkivr html-dokument")
("save image" "arkivr billede")
("save latex file" "arkivr latex-dokument")
("save tex file" "arkiver tex-dokument")
("save this buffer" "arkivr denne buffer")
("save verbatim file" "arkivr tekst-dokument")
("saved" "arkiveret")
("screen layout" "skrmlayout")
("screen margins" "skrmmargener")
("script" "index- og potenstegn")
("script above" "tegn over")
("script below" "tegn under")
("script script size" "indexes index strrelse")
("script size" "indexstrrelse")
("scripts not accepted" "scripts er ikke tilladt")
("search" "sg")
("searching" "sger")
("secondary" "sekundr")
("section" "afsnit")
("security" "sikkerhed")
("see" "se")
("select a document style" "vlg en dokumenttypografi")
("select a foreground color" "vlg en forgrundsfarve")
("select a language" "vlg et sprog")
("selected region" "valgte omrde")
("selection" "det valgte")
("selections" "det valgte")
("seminar" "seminar")
("separation between lines" "adskillelse mellem linier")
("separation between paragraphs" "adskillelse mellem paragraffer")
("separator" "seperator")
("september" "september")
("serb" "serbisk")
("series" "serier")
("series|right" "serier|hjre")
("session" "session")
("session name" "sessionsnavn")
("session type" "sessionstype")
("sessions" "sessioner")
("set" "indstil")
("set background color of cell" "indstil cellebaggrundsfarve")
("set cell mode" "indstil celletilstand")
("set extension center" "indstil udvidelsescentrum")
("set height" "indstil hjde")
("set height of cell" "indstil cellehjde")
("set margins" "indstil margener")
("set n" "indstil n")
("set paragraph margins" "indstil paragrafmargener")
("set paragraph mode" "indstil paragrafjustering")
("set printer dpi" "indstil printer oplsning")
("set printing command" "indstil udskrivningskommando")
("set span" "indstil spnd")
("set special cell properties" "indstil srlige celleegenskaber")
("set special table properties" "indstil srlige tabelegenskaber")
("set text width" "indstil tekstbredde")
("set width" "indstil bredde")
("set width of cell" "indstil cellebredde")
("settings" "indstillinger")
("setup printer" "indstil printer")
("shape" "form")
("shift-down" "skift-ned")
("shift-right" "skift-op")
("show" "vis")
("show header and footer" "vis sidehoved og -fod")
("show on screen" "vis p skrmen")
("shrinking factor" "formindskelsesfaktor")
("signature" "underskrift")
("size" "strrelse")
("size limits" "grnser for strrelsen")
("slanted" "skrnende")
("sloppy" "sjusket")
("small" "lille")
("small caps" "sm bogstaver")
("small figure" "lille figur")
("small skip" "lille mellemrum")
("small table" "lille tabel")
("source code" "kildekode")
("space" "mellemrum")
("space between lines" "mellemrum mellem linier")
("space between paragraphs" "mellemrum mellem paragraffer")
("spacing" "mellemrum")
("spanish" "spansk")
("special" "srlig")
("special cell properties" "srlige celleegenskaber")
("special table properties" "srlige tabelegenskaber")
("specific" "specifik")
("spell" "stavekontrol")
("spell checking complete" "stavekontrol afsluttet")
("spelling error" "stavefejl")
("spelling errors have been corrected" "stavefejl er blevet rettet")
("split" "det")
("square root" "kvadratrod")
("start" "start")
("start a new chapter" "begynd p et nyt kapitel")
("start a new section" "begynd p et nyt afsnit")
("start an interactive session" "start en interaktiv session")
("status bar" "statusbjlke")
("stretchable" "strkbar")
("stretchable horizontal" "vandret strkbar")
("stretchable vertical" "lodret strkbar")
("stroke" "indtastning")
("strokes" "indtastninger")
("strong" "kraftig")
("structural" "strukturel")
("style" "typografi")
("styles" "typografier")
("sub" "under")
("subparagraph" "underparagraf")
("subscript" "indextegn")
("subsection" "underafsnit")
("subsub" "underunder")
("subsubsection" "underunderafsnit")
("summary" "opsummering")
("summary of the principal TeXmacs tags" "opsummering af de vigtigste TeXmacs-tags")
("superpose" "overprg")
("superposed" "overprget")
("superscript" "potenstegn")
("swedish" "svensk")
("switch" "kontakt")
("switch to first" "skift til frste")
("switch to formula style" "skift til formeltypografi")
("switch to last" "skift til sidste")
("switch to next" "skift til nste")
("switch to previous" "skift til forrige")
("switching and folding" "kontakter og foldning")
("symbol" "symbol")
("system environment variables" "systemomrdevariable")
("tab" "tabulator")
("table" "tabel")
("table command" "tabelkommando")
("table of contents" "indholdsfortegnelse")
("tables" "tabeller")
("tabular" "tabel")
("tabular material" "tabeller")
("teXmacs as an interface" "teXmacs som en grnseflade")
("teXmacs fonts" "teXmacs skrifter")
("teXmacs notice" "teXmacsnote")
("teXmacs style files" "teXmacs typografidokumenter")
("ternary" "tertir")
("test" "prve")
("tex" "tex")
("text" "tekst")
("text font" "tekstskrift")
("text height correction" "korrektion af teksthjde")
("text width" "tekstbredde")
("texts" "tekster")
("th century bc" "te rhundrede fkr")
("th root" "te rod")
("thai" "thailandsk")
("the TeXmacs authors" "TeXmacs' forfattere")
("the application did not send its usual startup banner" "programmet gav os ikke det normale startbanner")
("the application does not reply" "programmet svarer ikke")
("the application is already running" "programmet krer allerede")
("the boxes produced by the typesetter" "de af typesetteren fremstillede kasser")
("the graphical user interface" "det grafiske brugerflade")
("the leaves of TeXmacs trees" "bladene p TeXmacstret")
("the mycas example" "mycas eksemplet")
("the primitive TeXmacs constructs" "de basale TeXmacskonstruktioner")
("the standard TeXmacs styles" "standard typografierne i TeXmacs")
("theorem" "theorem")
("there are unsaved files" "der er dokumenter der ikke er arkiveret")
("this buffer has not been saved" "denne buffer er ikke arkiveret")
("this document has been produced using" "dette dokument er fremstillet med")
("this line" "denne linie")
("this page" "denne side")
("tilda" "tilde")
("tilde" "tilde")
("times" "times")
("tiny" "lillebitte")
("title" "titel")
("to the left" "til venstre")
("to the right" "til hjre")
("today" "i dag")
("tools" "redskaber")
("top" "top")
("top border" "verste kant")
("top level" "verste niveau")
("top margin" "vertste margen")
("top padding" "verste mellemrum")
("translate" "overst")
("tree" "tr")
("tuple" "tuple")
("turkish" "tyrkisk")
("tutorial" "vejledning")
("type" "type")
("type a latex command followed by" "skriv en latex kommando fulgt af")
("type body" "skriv brdtekst")
("type denominator" "skriv nvner")
("type numerator" "skriv tller")
("type script" "skriv script")
("typesetted boxes" "typesettede kasser")
("typewriter" "skrivemaskine")
("typewriter small caps" "sm skrivemaskinebogstaver")
("typing a simple text" "at skrive en enkel tekst")
("typing simple texts" "skriv enkle tekster")
("ugaritic" "ugaritisk")
("ukrainian" "ukrainsk")
("underbrace" "underbrace")
("underline" "understreg")
("undo" "fortryd")
("undo last changes" "fortryd de sidste ndringer")
("up" "op")
("update" "opdatr")
("update from web" "opdatr fra internettet")
("update image links" "opdatr billledelinks")
("upper border" "vre ramme")
("use TeXmacs" "brug TeXmacs")
("use a black color" "brug en sort farve")
("use a blue color" "brug en bl farve")
("use a bold font" "brug en fed skrift")
("use a brown color" "brug en brun farve")
("use a calligraphic font" "brug en kalligrafisk skrift")
("use a green color" "brug en grn farve")
("use a grey color" "brug en gr farve")
("use a magenta color" "brug en magenta farve")
("use a orange color" "brug en orange farve")
("use a pink color" "brug en pink farve")
("use a red color" "brug en rd farve")
("use a sans serif font" "brug en sans serif skrift")
("use a typewriter font" "brug en skrivemaskineskrift")
("use a white color" "brug en hvid farve")
("use a yellow color" "brug en gul")
("use blackboard bold font" "brug fed blackboard")
("use bold font series" "brug den fede skriftserie")
("use calligraphical font" "brug kalligrafisk skrift")
("use footnote font size" "brug fodnoteskriftstrrelse")
("use fraktur font" "brug fraktuskrift")
("use huge font size" "brug enorm skriftstrrelse")
("use italic font shape" "brug skrstillet skriftform")
("use large font size" "brug stor skriftstrrelse")
("use left hand column as border" "brug venstre sjle som kant")
("use medium font series" "brug medium skriftserier")
("use normal font size" "brug normal skriftstrrelse")
("use package" "brug pakke")
("use paragraph width" "brug paragrafbredde")
("use really huge font size" "brug virkelig enorm skriftstrrelse")
("use right font shape" "brug hjre skriftform")
("use right hand column as border" "brug hjre sjle som kant")
("use roman font family" "brug serif skriftfamilie")
("use row above as border" "brug rkken over som kant")
("use row below as border" "brug rkken under som kant")
("use sans serif font family" "brug sans serif skriftfamilie")
("use script font size" "brug scriptskriftstrrelse")
("use slanted font shape" "brug skrnende skriftform")
("use small capitals" " sm kapitler")
("use small font size" "brug lille skriftstrrelse")
("use small-caps font shape" "brug sm kaptler skriftform")
("use the blackboard bold font" "brug den fede blackboard-skrift")
("use the fraktur font" "brug frakturskriften")
("use tiny font font size" "brug lillebitte skriftstrrelse")
("use typewriter font family" "brug skrivemaskineskriftfamilien")
("use very large font size" "brug meget stor skriftstrrelse")
("user manual" "brugerhndbog")
("user provided icons" "ikoner lavet af brugerne")
("users of Cyrillic languages" "brugere af kyrilliske sprog")
("value" "vrdi")
("variable" "variabel")
("variant" "variant")
("vector" "vektor")
("verbatim" "ordret")
("verse" "vers")
("vertical" "lodret")
("vertical after" "lodret efter")
("vertical before" "lodret fr")
("vertical cell alignment" "lodret cellejustering")
("vertical part" "lodret del")
("vertical position" "lodret placering")
("vertical space" "lodret mellemrum")
("vertical table alignment" "lodret tabeljustering")
("vertically align cell to the base" "justr cellen til bunden lodret")
("vertically center the cell" "centrer cellen lodret")
("very large" "meget stor")
("very small" "meget lille")
("vietnamese" "vietnamesisk")
("view" "vis")
("visible" "synlig")
("warning" "advarsel")
("welcome" "velkommen")
("welcome to GNU TeXmacs" "velkommen til GNU TeXmacs")
("what is new" "nyheder")
("when finished" "nr frdigtgjort")
("while" "mens")
("white" "hvid")
("wide accent" "bred accent")
("wide bar" "bred bjlke")
("width" "bredde")
("width is exactly the specified width" "bredde er prcis det specificerede")
("width is maximum of specified width and box width" "bredde er maksimum af det specificerede og kassebredde")
("width is minimum of specified width and box width" "bredde er minimum af det specificerede og kassebredde")
("width magnification" "breddeforstrrelse")
("window" "vindue")
("window height" "vinduehjde")
("window width" "vinduebredde")
("windows key" "windowstast")
("with" "med")
("write a name" "skriv et navn")
("write bold mathematics" "skriv fede formler")
("write bold text" "skriv fed tekst")
("write italic text" "skriv kursiv tekst")
("write sample text" "skriv eksempeltekst")
("write strong text" "skriv kraftig tekst")
("write typewriter text" "skriv skrivemaskinetekst")
("write verbatim text" "skriv ordret tekst")
("writing data converters" "skriv dataoversttere")
("writing your own style files" "skriv dine egne typografidokumenter")
("yellow" "gul")
("you can also obtain" "du kan ogs f")
("your document is back in its original state" "dit dokument er tilbage i dets oprindelige tilstand")
("your first interface" "din frste grnseflade")
("autosave" "autoarkiver")
("background evaluations" "baggrundsudregninger")
("basic communication using pipes" "simpel kommunikation ved brug af viderefringer")
("completion" "frdiggrelse")
("contact" "kontakt")
("contribute" "deltag")
("disable" "sl fra")
("download" "download")
("fold input field" "fold indtastningsfelt")
("formatted and structured output" "formateret og struktureret resultat")
("hybrid command" "hybridkommando")
("input mode" "indtastningstilstand")
("insert fields" "indst felter")
("insert input field above" "indst indtastningsfelt over")
("insert input field below" "indst indtastningsfelt under")
("insert macro" "indst makro")
("insert text field" "indst tekstfelt")
("insert value" "indst verdi")
("mathematical and customized input" "matematisk og brugerdefineret indtastning")
("mathematical input" "matematisk indtastning")
("miscellaneous features" "diverse funktioner")
("multiline input" "flerlinie indtastning")
("my documents" "mine dokumenter")
("next" "nste")
("no matches found for" "ingen fundne mage til")
("plugin" "udvidelse")
("plugins" "udvidelser")
("previous" "forrige")
("prompts and default input" "prompter og standardindtastninger")
("remove all output fields" "fjern alle resultatfelter")
("remove fields" "fjern felter")
("remove input field" "fjern indtastningsfelt")
("remove input field above" "fjern indtastningsfelt over")
("search results for" "resultaterne af sgningen efter")
("search words in my documents" "sg efter ord i mine dokumenter")
("search words in the documentation" "sg efter ord i brugerhndbgerne")
("search words in the source code" "sg efter ord i kildekoden")
("sending commands to TeXmacs" "give TeXmacs kommandoer")
("slovene" "slovensk")
("split session" "delt session")
("teXmacs plugins" "teXmacsudvidelser")
("your language" "dit sprog")
("a series" "a serien")
("activate once" "aktivr n gang")
("activation" "aktivering")
("american" "amerikansk")
("angular" "vinkler")
("apply macro" "anvend makro")
("apply macro once" "anvend makro n gang")
("arch series" "arch serien")
("b series" "b serien")
("closing style" "afslutningstype")
("common formats" "almindelige strrelser")
("compactification" "kompaktificering")
("compactify" "kompaktificr")
("control the evaluation of expressions" "kontrollr udregningen")
("detailed" "detaljerede")
("disactivate" "sl fra")
("disactivate once" "sl fra n gang")
("edit source tree" "redigr kildetr")
("formatting" "formattering")
("functional" "funktionel")
("informative flags" "beskrivende flag")
("inline arguments" "indbyggede argumenter")
("insert a condition" "indst en betingelse")
("insert a control flow instruction" "indst en flow-kontrol instruktion")
("insert a numerical operation" "indst en numerisk operation")
("insert a textual operation" "indst en tekstuel operation")
("insert an operation on tuples" "indst en tupel-operation")
("maximal" "maksimale")
("minimal" "minimale")
("only inline tags" "kun inline tags")
("repeat" "gentag")
("set or get environment variables" "indstil eller vis systemvariabler")
("source tags" "kilde-tags")
("standard formats" "standardformater")
("stretch" "strk")
("stretched" "strukket")
("write a macro" "skriv en makro")
("automatic quotes" "automatiske citationstegn")
("swiss" "schweizisk")
("presentation tag" "prsentationsmrke")
("reference guide for the TeXmacs primitives" "TeXmacs' urtyper")
("reference guide for the standard TeXmacs styles" "TeXmacs' standardtypografier")
("font type" "skrifttype")
("preview command" "se udskrift p skrm med")
("the buffer has not been saved" "bufferen er ikke arkiveret")
("recover autosave file" "gendan automatisk arkiveret dokument")
("short" "korte")
("mathematical font" "formelskrift")
("program font" "programskrift")
("web" "internet")
("create web site" "lav hjemmeside")
("source" "kildekode")
("long macro" "lang makro")
("compound" "sammensat")
("get label" "hent mrke")
("get arity" "hent aritet")
("map arguments" "kortlg argumenter")
("quasiquote" "quasicitering")
("unquote" "slut citering")
("unevaluated value" "ikke-udregnet vrdi")
("unevaluated argument" "ikke-udregnet argument")
("evaluation" "udregning")
("flow control" "flow-kontrol")
("for each" "for hver")
("find file" "find arkiv")
("display style" "vis typografi")
("two dots" "to prikker")
("circle" "cirkel")
("activate hidden" "aktivr skjult")
("add package" "tilfj pakke")
("alternative specification" "altenativ specifikation")
("even page left margin" "lige sides venstre margen")
("even page shift" "lige sideskift")
("general note" "hovednote")
("hidden" "skjult")
("homepage" "hjemmeside")
("insert author" "indst forfatter")
("insert title" "indst titel")
("mutator tags" "")
("new double page" "ny dobbeltside")
("new double page before" "ny dobbeltside fr")
("odd page left margin" "ulige sides venstre margen")
("odd page right margin" "ulige sides hjre margen")
("odd page shift" "ulige sideskift")
("reference guide" "manual")
("remove package" "fjern pakke")
("show hidden" "vis skjulte")
("standard TeXmacs styles" "standard TeXmacs typografier")
("standard environment variables" "standard omrdevariabler")
("stylesheet language" "typografiarkssprog")
("subtitle" "undertitel")
("the TeXmacs format" "TeXmacs formatet")
("upright" "opretstende")
("written with TeXmacs" "skrevet med TeXmacs")

